# Geoguessr Self-Hosted Reimplementation

## Build Docker Image Tarball

```bash
./docker/build.sh
```

## API

```
API Endpoints
GET /
    Returns 200 and {
        "version": string,
        "status": string
    }
PUT /game
    Accepts {
        "timer": number
        "rounds": number
    }
    Returns 200 and {
        "gameId": string
    }
GET /game/{ID}
    Returns 404 vs 200 and {
        "gameId": string,
        "timer": number,
        "coords": {
            "1": {
                "lat": number,
                "lng": number,
            }, ...
        },
        "players": [
            {
                "name": string,
                "currentRound": string || null,
                "totalScore": number,
                "guesses": {
                    "1": {
                        "lat": number,
                        "lng": number,
                        "score": number
                    }, ...
                }
            }, ...
        ]
    }
POST /game/{ID}/join
    Accepts {
        "playerName": string
    }
    Returns (401, 404, 409) vs 201 and {
        "playerId": string
    }
GET /game/{ID}/current
    Header Authorization: Player string
    Returns (400, 404) vs 200 and {
        "currentRound": string || null,
        "coord": {
            "lat": number,
            "lng": number,
        } || null,
        "timer": number
    }
POST /game/{ID}/guesses/{round}
    Header Authorization: Player string
    Accepts {
        "lat": number,
        "lng": number
    } OR {
        "timeout": boolean
    }
    Returns (400, 401, 404, 409) vs 201 and {
        "score": number,
        "totalScore": number,
        "distance": number || null,
    }
```

## Next Steps

- Improve scoring math
- Improve MapCrunch logic to distribute countries
- Asynchronously generate locations, allowing game creation to appear faster
- Update UI to create game without providing a name
- Error handling in UI
- Re-join a game you did not finish
- Optimize docker file or set up compose structure
- Override google controls in streetview, make custom divs
